﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Data;
using C1.Silverlight.FlexGrid;


namespace SL_Flex_ChartDataBinding
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            _flex.ItemsSourceChanged += new EventHandler(_flex_ItemsSourceChanged);

            // build data source
            var view = Product.GetProducts(200);

            //// set up grouping
            var gd = view.GroupDescriptions;
            gd.Add(new PropertyGroupDescription("Color"));   // group by product line            

            // assign data source to grid
            _flex.ItemsSource = view;

            // provide choices in grid editors
            _flex.Columns["Line"].ValueConverter = new ColumnValueConverter(Product.GetLines(), true);
            _flex.Columns["Color"].ValueConverter = new ColumnValueConverter(Product.GetColors(), false);

            // needed to show aggregates
            _flex.AreRowGroupHeadersFrozen = false;

            foreach (string s in "Price,Cost,Weight,Volume".Split(','))
            {
                _flex.Columns[s].GroupAggregate = Aggregate.Sum;
            }

            _flex.CollectionView.CurrentChanging += new System.ComponentModel.CurrentChangingEventHandler(CollectionView_CurrentChanging);
        }

        void CollectionView_CurrentChanging(object sender, System.ComponentModel.CurrentChangingEventArgs e)
        {
            UpdateChart();
        }

        void _flex_ItemsSourceChanged(object sender, EventArgs e)
        {
            UpdateChart();
        }

        public void UpdateChart()
        {
            c1Chart1.Data.Children.Clear();
            c1Chart1.Data.ItemNames = null;

            List<GroupRow> grt = new List<GroupRow>();

            foreach (Row gr in _flex.Rows)
            {
                if (gr.GetType() == typeof(C1.Silverlight.FlexGrid.GroupRow))
                {
                    GroupRow grw = gr as GroupRow;
                    grt.Add(grw);
                }

            }

            c1Chart1.Data.ItemsSource = grt;
            c1Chart1.Data.ItemNameBinding = new Binding("Group.Name");

            Binding bnd = new Binding();
            bnd.Path = new PropertyPath("");
            bnd.Converter = new CostValueConverter("Cost");
            c1Chart1.Data.Children.Add(new C1.Silverlight.Chart.DataSeries() { ValueBinding = bnd });

        }

    }

    class CostValueConverter : IValueConverter
    {
        string _field;
        public CostValueConverter(string field)
        {
            _field = field;
        }
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return (value as GroupRow).GetDataRaw((value as GroupRow).Grid.Columns[_field]);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }
}
